4.51. umbra.ui.widgets.active_QLabelsCollection — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.51. umbra.ui.widgets.active_QLabelsCollection

active_QLabel.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Active_QLabelsCollection` class.

Others:

## 4.51.1. Module Attributes

`umbra.ui.widgets.active_QLabelsCollection.` `LOGGER`

## 4.51.2. Classes

class `umbra.ui.widgets.active_QLabelsCollection.` `Active_QLabelsCollection`(parent=None)

  Bases: `PyQt4.QtCore.QObject`

  This class is a QObject subclass providing a group for `umbra.ui.widgets.active_QLabel.Active_QLabel` class objects.

  Parameters: | parent – Widget parent. ( QObject )

  `activeLabelClicked`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been clicked. ( pyqtSignal )

    Returns: | Current clicked active label. ( Active_QLabel )

  `activeLabelPressed`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been pressed. ( pyqtSignal )

    Returns: | Current clicked active label. ( Active_QLabel )

  `activeLabelReleased`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been released. ( pyqtSignal )

    Returns: | Current clicked active label. ( Active_QLabel )

  `activeLabelToggled`

    This signal is emited by the `Active_QLabelsCollection` class when one of its `umbra.ui.widgets.active_QLabel.Active_QLabel` child has been toggled. ( pyqtSignal )

    Returns: | Current checked active label. ( Active_QLabel )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `activeLabels`

    This method is the property for self.__activeLabels attribute.

    Returns: | self.__activeLabels. ( List )

  `addActiveLabel`(activeLabel)

    This method adds given Active_QLabel Widget.

    Parameters: | activeLabel – Active label to add. ( Active_QLabel )
    Returns: | Method success. ( Boolean )

  `removeActiveLabel`(activeLabel)

    This method removes given Active_QLabel Widget.

    Parameters: | activeLabel – Active label to remove. ( Active_QLabel )
    Returns: | Method success. ( Boolean )

  `getToggledActiveLabel`()

    This method returns the toggled Active_QLabel Widget.

    Returns: | Checked active label. ( Boolean )

  `getActiveLabelIndex`(activeLabel)

    This method returns given Active_QLabel Widget index.

    Parameters: | activeLabel – Active label to retrieve index. ( Active_QLabel )
    Returns: | Active label index. ( Integer )

  `getActiveLabelFromIndex`(index)

    This method returns the Active_QLabel Widget from given index.

    Parameters: | index – Index. ( Integer )
    Returns: | Active label. ( Active_QLabel )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »